<?php

namespace Test\Test\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Test\Test\Http\Requests\Jobs2018Request;
use Test\Test\Models\Jobs2018;

/**
 * Admin web controller class.
 */
class Jobs2018WorkflowController extends BaseController
{

    /**
     * Workflow controller function for jobs2018.
     *
     * @param Model   $jobs2018
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(Jobs2018Request $request, Jobs2018 $jobs2018, $step)
    {

        try {

            $jobs2018->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('test::jobs2018.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/jobs2018/jobs2018/' . $jobs2018->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/jobs2018/jobs2018/' . $jobs2018->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for jobs2018.
     *
     * @param Model   $jobs2018
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
     */

    public function getWorkflow(Jobs2018 $jobs2018, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $jobs2018->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('test::jobs2018.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('test::admin.jobs2018.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('test::admin.jobs2018.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('test::admin.jobs2018.message', $data)->render();

        }

    }
}
