<?php

namespace Test\Test\Workflow;

use Test\Test\Models\Jobs2018;
use Validator;

class Jobs2018Validator
{

    /**
     * Determine if the given jobs2018 is valid for complete status.
     *
     * @param Jobs2018 $jobs2018
     *
     * @return bool / Validator
     */
    public function complete(Jobs2018 $jobs2018)
    {
        return Validator::make($jobs2018->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given jobs2018 is valid for verify status.
     *
     * @param Jobs2018 $jobs2018
     *
     * @return bool / Validator
     */
    public function verify(Jobs2018 $jobs2018)
    {
        return Validator::make($jobs2018->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given jobs2018 is valid for approve status.
     *
     * @param Jobs2018 $jobs2018
     *
     * @return bool / Validator
     */
    public function approve(Jobs2018 $jobs2018)
    {
        return Validator::make($jobs2018->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given jobs2018 is valid for publish status.
     *
     * @param Jobs2018 $jobs2018
     *
     * @return bool / Validator
     */
    public function publish(Jobs2018 $jobs2018)
    {
        return Validator::make($jobs2018->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given jobs2018 is valid for archive status.
     *
     * @param Jobs2018 $jobs2018
     *
     * @return bool / Validator
     */
    public function archive(Jobs2018 $jobs2018)
    {
        return Validator::make($jobs2018->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given jobs2018 is valid for unpublish status.
     *
     * @param Jobs2018 $jobs2018
     *
     * @return bool / Validator
     */
    public function unpublish(Jobs2018 $jobs2018)
    {
        return Validator::make($jobs2018->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
